@@ -374,7 +374,7 @@ init_canvi (void)
 	
 	pb = gdk_pixbuf_new_from_file (BUDDY_DATADIR "/bug-buddy.png", NULL);
 	druid_data.throbber_pb = gdk_pixbuf_scale_simple (pb, 24, 24, GDK_INTERP_BILINEAR);
-	gdk_pixbuf_unref (pb);
+	g_object_ref (pb);
 
 	druid_data.throbber =
 		gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
@@ -387,17 +387,6 @@ init_canvi (void)
 				       NULL);
 }
 
-static gint
-check_intro_skip (gpointer data)
-{
-	if (druid_data.already_run && 
-	    gtk_toggle_button_get_active (
-		    GTK_TOGGLE_BUTTON (GET_WIDGET ("intro-skip-toggle"))))
-		on_druid_next_clicked (NULL, NULL);
-
-	return FALSE;
-}
-
 /* there should be no setting of default values here, I think */
 static void
 init_ui (void)
@@ -416,6 +405,8 @@ init_ui (void)
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (w), FALSE);
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (w), FALSE);
 
+	druid_data.gnome_version = g_getenv ("BUG_BUDDY_GNOME_VERSION");
+
 	/* dialog crash page */
 	s = popt_data.app_file;
 	if (!s) {
@@ -493,6 +484,17 @@ init_ui (void)
 		      "use_underline", TRUE,
 		      NULL);
 
+	{
+		GtkButtonBox *bbox;
+		
+		bbox = GTK_BUTTON_BOX (GET_WIDGET ("druid-bbox"));
+		gtk_button_box_set_child_secondary (
+			bbox, GET_WIDGET ("druid-help"), TRUE);
+		gtk_button_box_set_child_secondary (
+			bbox, GET_WIDGET ("druid-about"), TRUE);
+	}
+		
+
 #if 0
 	/* set the cursor at the beginning of the second line */
 	{
@@ -500,7 +502,7 @@ init_ui (void)
 		GtkTextIter iter;
 
 		buffy = gtk_text_view_get_buffer (GTK_TEXT_VIEW (GET_WIDGET ("desc-text")));
-		gtk_text_buffer_get_iter_at_line (buffer, &iter, 2);
+		gtk_text_buffer_get_iter_at_line (buffy, &iter, 2);
 	}
 #endif
 }
@@ -567,9 +569,18 @@ main (int argc, char *argv[])
 
 	gtk_widget_show (GET_WIDGET ("druid-window"));
 
-	gtk_idle_add (check_intro_skip, NULL);
+	if (getenv ("BUG_ME_HARDER"))
+		gtk_widget_show (GET_WIDGET ("progress-window"));
 	
-	druid_set_state (STATE_INTRO);
+	druid_set_state (STATE_INTRO);	
+
+	if (druid_data.already_run && 
+	    gtk_toggle_button_get_active (
+		    GTK_TOGGLE_BUTTON (GET_WIDGET ("intro-skip-toggle"))))
+		on_druid_next_clicked (NULL, NULL);
+
+	load_bugzillas ();
+
 
 	gtk_main ();
 
